@@ -13,10 +13,10 @@ class Person(CreateSendBase):
     self.email_address = email_address
     super(Person, self).__init__(auth)
 
-  def get(self, client_id, email_address):
+  def get(self, client_id=None, email_address=None):
     """Gets a person by client ID and email address."""
-    params = { "email": email_address }
-    response = self._get("/clients/%s/people.json" % client_id, params=params)
+    params = { "email": email_address or self.email_address }
+    response = self._get("/clients/%s/people.json" % (client_id or self.client_id), params=params)
     return json_to_py(response)
 
   def add(self, client_id, email_address, name, access_level, password):
@@ -28,7 +28,7 @@ class Person(CreateSendBase):
       "Password": password}
     response = self._post("/clients/%s/people.json" % client_id, json.dumps(body))
     return json_to_py(response)
-  
+
   def update(self, new_email_address, name, access_level, password = None):
     """Updates the details for a person. Password is optional and is only updated if supplied."""
     params = { "email": self.email_address }
@@ -37,10 +37,10 @@ class Person(CreateSendBase):
       "Name": name,
       "AccessLevel": access_level,
       "Password": password}
-    response = self._put("/clients/%s/people.json" % self.client_id, 
+    response = self._put("/clients/%s/people.json" % self.client_id,
       body=json.dumps(body), params=params)
     # Update self.email_address, so this object can continue to be used reliably
-    self.email_address = new_email_address  
+    self.email_address = new_email_address
 
   def delete(self):
     """Deletes the person from the client."""
