@@ -7,22 +7,22 @@ class SegmentTestCase(object):
 
   def test_create(self):
     list_id = "2983492834987394879837498"
-    rules = [ { "Subject": "EmailAddress", "Clauses": [ "CONTAINS example.com" ] } ]
+    rulegroups =  [ { "Rules": [ { "RuleType": "EmailAddress", "Clause": "CONTAINS example.com" },  { "RuleType": "Name", "Clause": "EQUALS subscriber" } ] } ]
     s = Segment()
-    s.stub_request("segments/%s.json" % list_id, "create_segment.json")
-    segment_id = s.create(list_id, "new segment title", rules)
+    s.stub_request("segments/%s.json" % list_id, "create_segment.json", None, "{\"RuleGroups\": [{\"Rules\": [{\"Clause\": \"CONTAINS example.com\", \"RuleType\": \"EmailAddress\"}, {\"Clause\": \"EQUALS subscriber\", \"RuleType\": \"Name\"}]}], \"Title\": \"new segment title\"}")
+    segment_id = s.create(list_id, "new segment title", rulegroups)
     self.assertEquals(segment_id, "0246c2aea610a3545d9780bf6ab890061234")
     self.assertEquals(s.segment_id, "0246c2aea610a3545d9780bf6ab890061234")
 
   def test_update(self):
-    rules = [ { "Subject": "Name", "Clauses": [ "EQUALS subscriber" ] } ]
-    self.segment.stub_request("segments/%s.json" % self.segment.segment_id, None)
-    self.segment.update("new title for segment", rules)
+    rulegroups = [ { "Rules": [ { "RuleType": "Name", "Clause": "EQUALS subscriber" } ] } ]
+    self.segment.stub_request("segments/%s.json" % self.segment.segment_id, None, "{\"Rules\": [{\"Clause\": \"EQUALS subscriber\", \"RuleType\": \"Name\"}], \"Title\": \"new title for segment\"}")
+    self.segment.update("new title for segment", rulegroups)
 
-  def test_add_rule(self):
-    clauses = [ "CONTAINS example.com" ]
-    self.segment.stub_request("segments/%s/rules.json" % self.segment.segment_id, None)
-    self.segment.add_rule("EmailAddress", clauses)
+  def test_add_rulegroup(self):
+    rulegroup = { "Rules": [ { "RuleType": "EmailAddress", "Clause": "CONTAINS example.com" } ] }
+    self.segment.stub_request("segments/%s/rules.json" % self.segment.segment_id, None, None, "{\"Rules\": [{\"Clause\": \"CONTAINS example.com\", \"RuleType\": \"EmailAddress\"}]}")
+    self.segment.add_rulegroup(rulegroup)
 
   def test_subscribers(self):
     min_date = "2010-01-01"
@@ -54,10 +54,11 @@ class SegmentTestCase(object):
     self.segment.stub_request("segments/%s.json" % self.segment.segment_id, "segment_details.json")
     res = self.segment.details()
     self.assertEquals(res.ActiveSubscribers, 0)
-    self.assertEquals(len(res.Rules), 2)
-    self.assertEquals(res.Rules[0].Subject, "EmailAddress")
-    self.assertEquals(len(res.Rules[0].Clauses), 1)
-    self.assertEquals(res.Rules[0].Clauses[0], "CONTAINS @hello.com")
+    self.assertEquals(len(res.RuleGroups), 2)
+    self.assertEquals(res.RuleGroups[0].Rules[0].RuleType, "EmailAddress")
+    self.assertEquals(res.RuleGroups[0].Rules[0].Clause, "CONTAINS @hello.com")
+    self.assertEquals(res.RuleGroups[1].Rules[0].RuleType, "Name")
+    self.assertEquals(res.RuleGroups[1].Rules[0].Clause, "PROVIDED")
     self.assertEquals(res.ListID, "2bea949d0bf96148c3e6a209d2e82060")
     self.assertEquals(res.SegmentID, "dba84a225d5ce3d19105d7257baac46f")
     self.assertEquals(res.Title, "My Segment")
